Add missing patch (webkitgtk-2.21.2-riscv64.patch)

Signed-off-by: David Abdurachmanov <david.abdurachmanov@gmail.com>
This commit is contained in:
David Abdurachmanov 2018-05-25 15:49:51 +02:00
parent 5511a8904e
commit 71cbf5b6f5
Signed by: davidlt
GPG Key ID: 7108702C938B13C1
1 changed files with 68 additions and 0 deletions

View File

@ -0,0 +1,68 @@
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 1903d6a1..07a92b22 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -99,6 +99,8 @@ elseif (LOWERCASE_CMAKE_SYSTEM_PROCESSOR MATCHES "ppc64")
set(WTF_CPU_PPC64 1)
elseif (LOWERCASE_CMAKE_SYSTEM_PROCESSOR MATCHES "ppc64le")
set(WTF_CPU_PPC64LE 1)
+elseif (LOWERCASE_CMAKE_SYSTEM_PROCESSOR MATCHES "riscv64")
+ set(WTF_CPU_RISCV64 1)
else ()
set(WTF_CPU_UNKNOWN 1)
endif ()
diff --git a/Source/JavaScriptCore/CMakeLists.txt b/Source/JavaScriptCore/CMakeLists.txt
index 5e56d50d..6a3c9620 100644
--- a/Source/JavaScriptCore/CMakeLists.txt
+++ b/Source/JavaScriptCore/CMakeLists.txt
@@ -227,6 +227,8 @@ else ()
set(OFFLINE_ASM_BACKEND "ARMv7_TRADITIONAL")
elseif (WTF_CPU_MIPS)
set(OFFLINE_ASM_BACKEND "MIPS")
+ elseif (WTF_CPU_RISCV64)
+ set(OFFLINE_ASM_BACKEND "RISCV64")
endif ()
if (NOT ENABLE_JIT)
diff --git a/Source/WTF/wtf/dtoa/utils.h b/Source/WTF/wtf/dtoa/utils.h
index 14a94785..a35a78d8 100644
--- a/Source/WTF/wtf/dtoa/utils.h
+++ b/Source/WTF/wtf/dtoa/utils.h
@@ -49,7 +49,7 @@
defined(__ARMEL__) || \
defined(_MIPS_ARCH_MIPS32R2)
#define DOUBLE_CONVERSION_CORRECT_DOUBLE_OPERATIONS 1
-#elif CPU(MIPS) || CPU(MIPS64) || CPU(PPC) || CPU(PPC64) || CPU(PPC64LE) || CPU(ARM64)
+#elif CPU(MIPS) || CPU(MIPS64) || CPU(PPC) || CPU(PPC64) || CPU(PPC64LE) || CPU(ARM64) || CPU(RISCV64)
#define DOUBLE_CONVERSION_CORRECT_DOUBLE_OPERATIONS 1
#elif defined(_M_IX86) || defined(__i386__)
#if defined(_WIN32)
diff --git a/Source/WTF/wtf/Platform.h b/Source/WTF/wtf/Platform.h
index 0fa30beb..aa0fb772 100644
--- a/Source/WTF/wtf/Platform.h
+++ b/Source/WTF/wtf/Platform.h
@@ -147,6 +147,11 @@
#endif
#endif
+/* CPU(RISCV64) - RISCV64 */
+#if defined(__riscv) && defined(__riscv_xlen) && __riscv_xlen == 64
+#define WTF_CPU_RISCV64 1
+#endif
+
/* CPU(ARM) - ARM, any version*/
#define WTF_ARM_ARCH_AT_LEAST(N) (CPU(ARM) && WTF_ARM_ARCH_VERSION >= N)
@@ -718,10 +723,10 @@
#endif
#endif /* !defined(USE_JSVALUE64) && !defined(USE_JSVALUE32_64) */
/* The JIT is enabled by default on all x86, x86-64, ARM & MIPS platforms except ARMv7k. */
#if !defined(ENABLE_JIT) \
&& (CPU(X86) || CPU(X86_64) || CPU(ARM) || (CPU(ARM64) && !defined(__ILP32__)) || CPU(MIPS)) \
- && !CPU(APPLE_ARMV7K)
+ && !(CPU(APPLE_ARMV7K) || CPU(RISCV64))
#define ENABLE_JIT 1
#endif
@@ -718,10 +723,10 @@
#endif
#endif /* !defined(USE_JSVALUE64) && !defined(USE_JSVALUE32_64) */
-/* The JIT is enabled by default on all x86, x86-64, ARM & MIPS platforms except ARMv7k. */
+/* The JIT is enabled by default on all x86, x86-64, ARM & MIPS platforms except ARMv7k & RISCV64. */
#if !defined(ENABLE_JIT) \
&& (CPU(X86) || CPU(X86_64) || CPU(ARM) || (CPU(ARM64) && !defined(__ILP32__)) || CPU(MIPS)) \